/*
ModbusMaster library was written by Doc Walker https://github.com/4-20ma/ModbusMaster

This code Turns On and Turns Off RKI-4449 1-Channel Modbus RTU Relay Module and shows status of the relay.

Connections of Sensor, Arduino and MAX485 TTL to RS485 Converter
Serial Port 0 is not used to connect to drive because its connected to USB-Serial and used to show information on console.

For Arduino Uno Software serial needs to be used as there is only one hardware serial port and its connected to USB-Serial. 
   Sensor         MAX485 TTL to RS485 Converter
     A+         -       A
     B-         -       B
    GND         -       GND
    
   MAX485 TTL to RS485 Converter    Arduino (Software Serial)
     R0                  -            D2              
     DE & RE             -            D8
     DI                  -            D3
     GND                 -            GND
   
For more information see :https://robokits.co.in/arduino/motor-control-boards/interface-boards/modbus-rtu-1-channel-1-way-relay-module-ttl-communication-output
*/

#include <ModbusMaster.h>   
#include <SoftwareSerial.h> 
SoftwareSerial mySerial(2,3);    //Software Serial port For Arduino Uno
#define MODBUS_DATA_TRANSACTION_PIN 8   //DE & RE Pin of MAX485
ModbusMaster node;                      //object for ModbusMaster

long int a1,a2;
uint8_t Slave_ID = 255;   //Slave ID of the Sensor

void setup() 
{
    pinMode(MODBUS_DATA_TRANSACTION_PIN, OUTPUT);
    digitalWrite(MODBUS_DATA_TRANSACTION_PIN, 0);
    Serial.begin(9600);     //Baud rate is 9600 8N1
    mySerial.begin(9600);   //Modbus Baud rate is 9600 8N1
    node.begin(mySerial);
    node.preTransmission(preTransmission);
    node.postTransmission(postTransmission);
    Serial.println("RKI-4449 1-Channel Modus RTU Relay Module");
    Serial.print("Slave ID :");
    Serial.println(Slave_ID);
}

void loop() 
{
   a1 = node.Turn_On_Relay1(Slave_ID); //Turn on relay for 5 seconds 
   Serial.print("Relay Status :"); 
   Serial.println(a1);
   delay(5000); 
       
   a2 = node.Turn_Off_Relay1(Slave_ID); //Turn off relay for 5 seconds
   Serial.print("Relay Status :");
   Serial.println(a2);  
   delay(5000);
}

void preTransmission() 
{
  digitalWrite(MODBUS_DATA_TRANSACTION_PIN, 1);
  delay(10);
}

void postTransmission()
{
  delay(2);
  digitalWrite(MODBUS_DATA_TRANSACTION_PIN, 0);
}
